Re-exports
pub use rand;
Structs
- Mondrian
- Rectangle
- StdRng
- The standard RNG. The PRNG algorithm in
StdRngis chosen to be efficient on the current platform, to be statistically strong and unpredictable (meaning a cryptographically secure PRNG).
Traits
- Seedable
Rng - A random number generator that can be explicitly seeded.
Functions
- save
- Save a document.
- thread_
rng - Retrieve the lazily-initialized thread-local random number generator,
seeded by the system. Intended to be used in method chaining style,
e.g.
thread_rng().gen::<i32>(), or cached locally, e.g.let mut rng = thread_rng();. Invoked by theDefaulttrait, makingThreadRng::default()equivalent.